%define api        1.0
%define major      0
%define qt5_name   qt5-gstreamer

Name:           qt-gstreamer
Summary:        C++ bindings for GStreamer with a Qt-style API
Version:        1.2.0
Release:        %mkrel 16
License:        LGPLv2+
Group:          Development/KDE and Qt
Url:            https://gstreamer.freedesktop.org/modules/qt-gstreamer.html
Source0:        https://gstreamer.freedesktop.org/src/%{name}/%{name}-%{version}.tar.xz
# Upstream fixes from master branch since release 1.2.0 (date: git_2018-05-05)
# https://cgit.freedesktop.org/gstreamer/qt-gstreamer/log/
Patch0:         qt-gstreamer-1.2.0-upstream-fixes-from-git_2018-05-05.patch
# OpenBSD patches
# Unbreak build with new Gstreamer 1.16
Patch10:        qt-gstreamer-1.2.0-openbsd-qgst_caps.patch
# Archlinux
# Unbreak build with new Gstreamer 1.18
Patch11:        qt-gstreamer-1.18.patch
Patch50:	qt-gstreamer-glib.patch
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Test)

BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  cmake
BuildRequires:  boost-devel
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  doxygen

%description
QtGStreamer provides C++ bindings for GStreamer with a Qt-style API,
plus some helper classes for integrating GStreamer better in Qt
applications.

#-------------------------------------------------------------------

%package -n %{qt5_name}
Summary:        C++ bindings for GStreamer with a Qt5-style API
Group:          Development/KDE and Qt

%description -n %{qt5_name}
Qt5GStreamer provides C++ bindings for GStreamer with a Qt-style API,
plus some helper classes for integrating GStreamer better in Qt5
applications.

%files -n %{qt5_name}
%_libdir/gstreamer-%{api}/libgstqt5videosink.so
%_qt5_qmldir/QtGStreamer/

#-------------------------------------------------------------------

%define libqt5glib %mklibname qt5glib 2.0 %{major}

%package -n %{libqt5glib}
Summary:        C++/Qt5 bindings for parts of the GLib and GObject APIs
Group:          System/Libraries

%description -n %{libqt5glib}
Library providing C++/Q5t bindings for parts of the GLib and GObject
APIs, a base on which Qt5GStreamer is built.

%files -n %{libqt5glib}
%_libdir/libQt5GLib-2.0.so.%{major}*
%_libdir/libQt5GLib-2.0.so.%{version}

#-------------------------------------------------------------------

%define libqt5gstreamer %mklibname qt5gstreamer %{api} %{major}

%package -n %{libqt5gstreamer}
Summary:        C++/Qt5 bindings for GStreamer
Group:          System/Libraries

%description -n %{libqt5gstreamer}
Library providing C++/Qt5 bindings for GStreamer.

%files -n %{libqt5gstreamer}
%_libdir/libQt5GStreamer-%{api}.so.%{major}*
%_libdir/libQt5GStreamer-%{api}.so.%{version}

#-------------------------------------------------------------------

%define libqt5gstreamerquick %mklibname qt5gstreamerquick %{api} %{major}

%package -n %{libqt5gstreamerquick}
Summary:        C++/Qt5 bindings for GStreamer
Group:          System/Libraries

%description -n %{libqt5gstreamerquick}
Library providing C++/Qt5 bindings for GStreamer.

%files -n %{libqt5gstreamerquick}
%_libdir/libQt5GStreamerQuick-%{api}.so.%{major}*
%_libdir/libQt5GStreamerQuick-%{api}.so.%{version}

#-------------------------------------------------------------------

%define libqt5gstreamerui %mklibname qt5gstreamerui %{api} %{major}

%package -n %{libqt5gstreamerui}
Summary:        Library providing integration with Qt5Gui
Group:          System/Libraries

%description -n %{libqt5gstreamerui}
Library providing integration with Qt5Gui.

%files -n %{libqt5gstreamerui}
%_libdir/libQt5GStreamerUi-%{api}.so.%{major}*
%_libdir/libQt5GStreamerUi-%{api}.so.%{version}

#-------------------------------------------------------------------

%define libqt5gstreamerutils %mklibname qt5gstreamerutils %{api} %{major}

%package -n %{libqt5gstreamerutils}
Summary:        Library providing some high level utility classes
Group:          System/Libraries

%description -n %{libqt5gstreamerutils}
Library providing some high level utility classes.

%files -n %{libqt5gstreamerutils}
%_libdir/libQt5GStreamerUtils-%{api}.so.%{major}*
%_libdir/libQt5GStreamerUtils-%{api}.so.%{version}

#--------------------------------------------------------------------

%define develnameQt5 %mklibname %{qt5_name} -d

%package -n %{develnameQt5}
Summary:        Development files for Qt5Gstreamer
Group:          Development/KDE and Qt

Requires:       %libqt5glib = %version-%release
Requires:       %libqt5gstreamer = %version-%release
Requires:       %libqt5gstreamerquick = %version-%release
Requires:       %libqt5gstreamerui = %version-%release
Requires:       %libqt5gstreamerutils = %version-%release
Requires:       boost-devel
Provides:       qt5-gstreamer-devel = %version-%release

%description -n %{develnameQt5}
Qt5GStreamer provides C++ bindings for GStreamer with a Qt-style API,
plus some helper classes for integrating GStreamer better in Qt5
applications.

This package contains files for developing applications using
Qt5Gstreamer.

%files -n %{develnameQt5}
%_includedir/Qt5GStreamer/
%dir %_libdir/cmake/Qt5GStreamer
%_libdir/cmake/Qt5GStreamer/*.cmake
%_libdir/libQt5GLib-2.0.so
%_libdir/libQt5GStreamer-%{api}.so
%_libdir/libQt5GStreamerQuick-%{api}.so
%_libdir/libQt5GStreamerUi-%{api}.so
%_libdir/libQt5GStreamerUtils-%{api}.so
%_libdir/pkgconfig/Qt5GLib-2.0.pc
%_libdir/pkgconfig/Qt5GStreamer-%{api}.pc
%_libdir/pkgconfig/Qt5GStreamerQuick-%{api}.pc
%_libdir/pkgconfig/Qt5GStreamerUi-%{api}.pc
%_libdir/pkgconfig/Qt5GStreamerUtils-%{api}.pc

#--------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%cmake_qt5 -DQT_VERSION=5 -DQTGSTREAMER_TESTS=OFF
%cmake_build

%install
%cmake_install


%changelog
* Mon Feb 13 2023 neoclust <neoclust> 1.2.0-16.mga9
+ Revision: 1941419
- Rebuild because of missing debug package

* Mon Apr 04 2022 umeabot <umeabot> 1.2.0-15.mga9
+ Revision: 1843744
- Mageia 9 Mass Rebuild

* Sat Sep 11 2021 wally <wally> 1.2.0-14.mga9
+ Revision: 1745133
- drop qt4 build
- clean old obsoletes and conflicts
- fix build with glib >= 2.68
- rebuild for boost 1.77.0

* Thu Dec 17 2020 umeabot <umeabot> 1.2.0-13.mga8
+ Revision: 1659559
- Rebuild for new Qt5

* Fri Nov 27 2020 tmb <tmb> 1.2.0-12.mga8
+ Revision: 1649787
- rebuild for missing signatures

* Sat Nov 21 2020 daviddavid <daviddavid> 1.2.0-11.mga8
+ Revision: 1648070
- add archlinux patch to fix build with new Gstreamer >= 1.18

* Sat Feb 15 2020 umeabot <umeabot> 1.2.0-10.mga8
+ Revision: 1527937
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros
- build with new cmake macros

* Sun Jul 28 2019 daviddavid <daviddavid> 1.2.0-9.mga8
+ Revision: 1424776
- backport in a single patch upstream fixes from master branch
  since release 1.2.0 (date: git_2018-05-05)
- add patch from OpenBSD to fix build with new Gstreamer

* Mon Apr 01 2019 umeabot <umeabot> 1.2.0-8.mga7
+ Revision: 1384397
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1.2.0-7.mga7
+ Revision: 1300706
- Mageia 7 Mass Rebuild

* Sun Jun 03 2018 daviddavid <daviddavid> 1.2.0-6.mga7
+ Revision: 1234331
- add patch to fix build with new Qt5 >= 5.11.0

* Mon Aug 07 2017 daviddavid <daviddavid> 1.2.0-5.mga7
+ Revision: 1138464
- disable qt5-qtquick1 support

* Fri Mar 18 2016 daviddavid <daviddavid> 1.2.0-4.mga6
+ Revision: 992797
- add two patches from fedora to support building against boost-1.60
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 28 2015 blino <blino> 1.2.0-3.mga6
+ Revision: 896085
- fix compilation with GStreamer >= 1.5.1 (from upstream)
- fix URL

* Fri Feb 06 2015 lmenut <lmenut> 1.2.0-2.mga5
+ Revision: 813770
- update to 1.2.0 (GStreamer 1.0)

* Wed Oct 15 2014 umeabot <umeabot> 0.10.3-3.mga5
+ Revision: 744317
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.10.3-2.mga5
+ Revision: 688522
- Mageia 5 Mass Rebuild

* Sun Sep 07 2014 lmenut <lmenut> 0.10.3-1.mga5
+ Revision: 673242
- update to 0.10.3
- fix libification
- build qt5-gstreamer
+ pterjan <pterjan>
- 0.10.3

* Sat Oct 19 2013 umeabot <umeabot> 0.10.2-5.mga4
+ Revision: 529597
- Mageia 4 Mass Rebuild

* Wed Jul 10 2013 fwang <fwang> 0.10.2-4.mga4
+ Revision: 452498
- rebuild for new boost

* Wed Mar 13 2013 neoclust <neoclust> 0.10.2-3.mga3
+ Revision: 402639
- Make devel package require boost-devel as it is an include in QtGStreamer/QGlib/global.h

* Sun Jan 13 2013 umeabot <umeabot> 0.10.2-2.mga3
+ Revision: 379920
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Aug 31 2012 mikala <mikala> 0.10.2-1.mga3
+ Revision: 285923
- Update tarball to 0.10.2
- Split the lib(64)qt-gstreamer library (it was providing 3 libraries)
- Add missing BR & use pkconfig() when it's possible

* Thu Apr 12 2012 mikala <mikala> 0.10.1.2-1.mga2
+ Revision: 230512
- Update tarball to 0.10.1.2
- Disable test for now (1 test fail)
- Fix files list
- Add patch1 to fix build against glib 2.31
- rediff patch0 in order to use %%apply_patches macro
- Remove %%clean & %%defattr()

* Thu Mar 03 2011 mikala <mikala> 0.10.1-1.mga1
+ Revision: 63726
- Drop BuildRoot
- imported package qt-gstreamer


* Fri Feb 04 2011 Funda Wang <fwang@mandriva.org> 0.10.1-1mdv2011.0
+ Revision: 635774
- install into correct libdir
- update url and group
- import qt-gstreamer

